package com.adc.da.vdaims.util;

import com.adc.da.vdaims.entity.FtpResultBean;
import org.apache.commons.net.ftp.FTP;
import org.apache.commons.net.ftp.FTPClient;
import org.apache.commons.net.ftp.FTPFile;
import org.apache.commons.net.ftp.FTPReply;

import java.io.*;

/**
 * ftp上传、下载文件工具类
 */
public class FtpUtil {
	/** 
     * Description: 向FTP服务器上传文件 
     * @param host FTP服务器hostname 
     * @param port FTP服务器端口 
     * @param username FTP登录账号 
     * @param password FTP登录密码 
     * @param basePath FTP服务器基础目录
     * @param filePath FTP服务器文件存放路径。例如分日期存放：/2015/01/01。文件的路径为basePath+filePath
     * @param filename 上传到FTP服务器上的文件名 
     * @param input 输入流 
     * @return 返回信息实体
     */  
    public static FtpResultBean uploadFile(String host, int port, String username, String password, String tempPath,
                                           String filename, InputStream input) {
    	FtpResultBean resultBean=new FtpResultBean();
        boolean result = false;
        String message="程序异常请重试";
        FTPClient ftp = new FTPClient();
        try {
            int reply;
            ftp.connect(host, port);// 连接FTP服务器
            // 如果采用默认端口，可以使用ftp.connect(host)的方式直接连接FTP服务器
            ftp.login(username, password);// 登录
            reply = ftp.getReplyCode();
            if (!FTPReply.isPositiveCompletion(reply)) {
                message="连接FTP服务器异常,请联系管理员";
            }else{
            	 //切换到上传目录
               /* if (!ftp.changeWorkingDirectory(tempPath)) {
                    //创建上传的路径  该方法只能创建一级目录，在这里如果/home/ftpuser存在则可创建image
                    //ftp.makeDirectory(tempPath);
                	message="文件传输目录不存在";
                }*/
                //设置上传文件的类型为二进制类型
                ftp.setFileType(FTP.BINARY_FILE_TYPE);
                //上传文件
                if (ftp.storeFile(filename, input)) {
                    result = true;
                    message="ftp上传文件成功";
                }
            }
            input.close();
            ftp.logout();
        } catch (IOException e) {
            e.printStackTrace();
        } finally {
            if (ftp.isConnected()) {
                try {
                    ftp.disconnect();
                } catch (IOException ioe) {
                	ioe.printStackTrace();
                }
            }
        }
        resultBean.setMessage(message);
        resultBean.setSuccess(result);
        return resultBean;
    }
    
    /** 
     * Description: 从FTP服务器下载文件 
     * @param host FTP服务器hostname 
     * @param port FTP服务器端口 
     * @param username FTP登录账号 
     * @param password FTP登录密码 
     * @param remotePath FTP服务器上的相对路径 
     * @param fileName 要下载的文件名 
     * @param localPath 下载后保存到本地的路径 
     * @return 
     */  
    public static boolean downloadFile(String host, int port, String username, String password, String remotePath,
            String fileName, String localPath) {
        boolean result = false;
        FTPClient ftp = new FTPClient();
        try {
            int reply;
            ftp.connect(host, port);
            // 如果采用默认端口，可以使用ftp.connect(host)的方式直接连接FTP服务器
            ftp.login(username, password);// 登录
            reply = ftp.getReplyCode();
            if (!FTPReply.isPositiveCompletion(reply)) {
                ftp.disconnect();
                return result;
            }
            ftp.changeWorkingDirectory(remotePath);// 转移到FTP服务器目录
            FTPFile[] fs = ftp.listFiles();
            for (FTPFile ff : fs) {
                if (ff.getName().equals(fileName)) {
                    File localFile = new File(localPath + "/" + ff.getName());

                    OutputStream is = new FileOutputStream(localFile);
                    ftp.retrieveFile(ff.getName(), is);
                    is.close();
                }
            }

            ftp.logout();
            result = true;
        } catch (IOException e) {
            e.printStackTrace();
        } finally {
            if (ftp.isConnected()) {
                try {
                    ftp.disconnect();
                } catch (IOException ioe) {
                }
            }
        }
        return result;
    }
    
    /*public static void main(String[] args) {
        try {  
            FileInputStream in=new FileInputStream(new File("C:\\vdaims\\template\\CerData_bf7734ad-cab7-4f44-a42d-6ecf913f0dff.pdf"));  
            FtpResultBean resultBean = FtpUtil.uploadFile("pdfs.vecc-mep.org.cn", 21, "62188593-x", "5jCxqtqtTCGTwk3n", "/2018-04","CerData1_bf7734ad-cab7-4f44-a42d-6ecf913f0dff.pdf", in);
            System.out.println(resultBean.getMessage());  
            System.out.println(resultBean.isSuccess());  
        } catch (FileNotFoundException e) {  
            e.printStackTrace();  
        }  
    }*/
}
