package com.adc.da.vdaims.util;

import com.google.zxing.BarcodeFormat;
import com.google.zxing.EncodeHintType;
import com.google.zxing.MultiFormatWriter;
import com.google.zxing.WriterException;
import com.google.zxing.common.BitMatrix;
import com.google.zxing.qrcode.decoder.ErrorCorrectionLevel;

import javax.imageio.ImageIO;
import java.awt.image.BufferedImage;
import java.io.File;
import java.io.IOException;
import java.io.OutputStream;
import java.util.Hashtable;

public class GoogleQRCodeUtil {
	private static final int BLACK = 0xFF000000;
	private static final int WHITE = 0xFFFFFFFF;
	 
	public static BufferedImage toBufferedImage(BitMatrix matrix) {
		int width = matrix.getWidth();
		int height = matrix.getHeight();
		BufferedImage image = new BufferedImage(width, height, BufferedImage.TYPE_INT_RGB);
		for (int x = 0; x < width; x++) {
			for (int y = 0; y < height; y++) {
				image.setRGB(x, y, matrix.get(x, y) ? BLACK : WHITE);
			}
		}
	return image;
	}
	
	public static void writeToFile(BitMatrix matrix, String format, File file) throws IOException {
		BufferedImage image = toBufferedImage(matrix);
		if (!ImageIO.write(image, format, file)) {
			throw new IOException("Could not write an image of format " + format + " to " + file);
		}
	}
	
	public static void writeToStream(BitMatrix matrix, String format, OutputStream stream) throws IOException {
		BufferedImage image = toBufferedImage(matrix);
		if (!ImageIO.write(image, format, stream)) {
			throw new IOException("Could not write an image of format " + format);
		}
	}
	
	public static void createQRCode(String text,int width,int height,String format,String path){
		Hashtable<EncodeHintType, Object> hints = new Hashtable<EncodeHintType, Object>();
		hints.put(EncodeHintType.ERROR_CORRECTION, ErrorCorrectionLevel.L);    
		hints.put(EncodeHintType.CHARACTER_SET, "utf-8");   // 内容所使用字符集编码
	    hints.put(EncodeHintType.MARGIN, 0);//设置二维码边的空度，非负数  
		BitMatrix bitMatrix = null;
		try {
			bitMatrix = new MultiFormatWriter().encode(text, BarcodeFormat.QR_CODE, width, height, hints);
			//File outputFile = new File("E:" + File.separator + "new.png");
			File outputFile = new File(path);
			if(!outputFile.exists()){
				outputFile.mkdirs();
			}
				GoogleQRCodeUtil.writeToFile(bitMatrix, format, outputFile);
		} catch (WriterException e) {
			e.printStackTrace();
		}
		   catch (IOException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
	}
	
	public static void main(String[] args) throws Exception {
		String text = "http://xxgk.vecc.org.cn/vin/343534546"; // 二维码内容
		int width = 200; // 二维码图片宽度
		int height = 200; // 二维码图片高度
		String format = "png";// 二维码的图片格式
		/*Hashtable<EncodeHintType, String> hints = new Hashtable<EncodeHintType, String>();
		hints.put(EncodeHintType.CHARACTER_SET, "utf-8");   // 内容所使用字符集编码
		BitMatrix bitMatrix = new MultiFormatWriter().encode(text, BarcodeFormat.QR_CODE, width, height, hints);
		//File outputFile = new File("E:" + File.separator + "new.png");
		File outputFile = new File("E://erweima3.png");
		if(!outputFile.exists()){
			outputFile.mkdirs();
		}
		GoogleQRCodeUtil.writeToFile(bitMatrix, format, outputFile);*/
		//String path="E://qr/erweima2.png";  width = 54 ,height = 54
		//String path="E://qr/erweima1.png";    width = 80 ,height = 80
		String path="E://qr/erweima3.png";
		createQRCode(text, width, height, format, path);
		}
}
