package com.adc.da.vdaims.util;


import com.adc.da.vdaims.exception.BusinessException;
import org.apache.http.HttpEntity;
import org.apache.http.client.config.RequestConfig;
import org.apache.http.client.methods.CloseableHttpResponse;
import org.apache.http.client.methods.HttpPost;
import org.apache.http.entity.ContentType;
import org.apache.http.entity.mime.HttpMultipartMode;
import org.apache.http.entity.mime.MultipartEntityBuilder;
import org.apache.http.entity.mime.content.FileBody;
import org.apache.http.impl.client.CloseableHttpClient;
import org.apache.http.impl.client.HttpClients;
import org.apache.http.util.EntityUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;


import java.io.*;

public class PDFUtils2 {

    private static final Logger log = LoggerFactory.getLogger(PDFUtils2.class);

    public static void wordToPdf(File wordFile, File pdfFile, String reqUrl) {
        RequestConfig requestConfig = RequestConfig.custom()
                .setSocketTimeout(10000)// 读取超时
                .setConnectTimeout(5000)// 连接超时
                .build();
        CloseableHttpClient httpClient = HttpClients.custom().setDefaultRequestConfig(requestConfig).build();

        HttpPost httpPost = new HttpPost(reqUrl);
        CloseableHttpResponse response = null;
        try {
            MultipartEntityBuilder builder = MultipartEntityBuilder.create();
            builder.setMode(HttpMultipartMode.BROWSER_COMPATIBLE);
            builder.addPart("file", new FileBody(wordFile, ContentType.MULTIPART_FORM_DATA, wordFile.getName()));
            HttpEntity httpEntity = builder.build();
            httpPost.setEntity(httpEntity);
            response = httpClient.execute(httpPost);
            int statecode = response.getStatusLine().getStatusCode();
            if (statecode == 200) {
                HttpEntity httpentity = response.getEntity();
                if (httpentity != null) {
                    FileOutputStream fileOutputStream = new FileOutputStream(pdfFile);
                    fileOutputStream.write(EntityUtils.toByteArray(httpentity));
                    return;
                }
            }
            throw new BusinessException("word转pdf失败");
        } catch (Exception e) {
            log.error("word转pdf服务调用失败", e);
            throw new BusinessException("word转pdf失败");
        } finally {
            try {
                if (response != null) {
                    response.close();
                }
            } catch (IOException e) {
                e.printStackTrace();
            }
            try {
                httpPost.abort();
            } catch (Exception e) {
                e.printStackTrace();
            }
            try {
                httpClient.close();
            } catch (IOException e) {
                e.printStackTrace();
            }
        }
    }

//    public static void main(String[] args) {
//        String url = "http://127.0.0.1:7008/api/wordToPdf";
//        long str = System.currentTimeMillis();
//        File file = new File("D:\\vdaims\\template\\uniData_931e208b0c1f409d84e222304c4739be.docx");
//        PDFUtils2.wordToPdf(file, new File("D:\\vdaims\\template\\uniData_931e208b0c1f409d84e222304c4739be.pdf"), url);
//        System.out.println("消耗：" + (System.currentTimeMillis() - str));
//    }
}
